OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Anda telah membuat papan {board} baru",
    "{user} has created a new board {board}" : "{user} telah membuat papan {board} baru",
    "You have deleted the board {board}" : "Anda telah menghapus papan {board}",
    "{user} has deleted the board {board}" : "{user} telah menghapus papan {board}",
    "You have restored the board {board}" : "Anda telah memulihkan papan {board}",
    "{user} has restored the board {board}" : "{user} telah memulihkan papan {board}",
    "You have shared the board {board} with {acl}" : "Anda telah membagikan papan {board} dengan akses {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} telah membagikan papan {board} dengan akses {acl}",
    "You have removed {acl} from the board {board}" : "Anda telah mencabut akses {acl} pada papan {board}",
    "{user} has removed {acl} from the board {board}" : "{user} telah mencabut akses {acl} pada papan {board}",
    "You have renamed the board {before} to {board}" : "Anda telah mengubah nama papan {before} menjadi {board}",
    "{user} has renamed the board {before} to {board}" : "{user} telah mengubah nama papan {before} menjadi {board}",
    "You have archived the board {board}" : "Anda telah mengarsipkan papan {board}",
    "{user} has archived the board {before}" : "{user} telah mengarsipkan papan {board}",
    "You have unarchived the board {board}" : "Anda telah memulihkan papan {board}",
    "{user} has unarchived the board {before}" : "{user} telah memulihkan papan {board}",
    "You have created a new list {stack} on board {board}" : "Anda telah membuat daftar baru {stack} pada papan {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} telah membuat daftar baru {stack} pada papan {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Anda telah mengubah nama daftar {before} menjadi {stack} pada papan {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} telah mengubah nama daftar {before} menjadi {stack} pada papan {board}",
    "You have deleted list {stack} on board {board}" : "Anda telah menghapus daftar {stack} pada papan {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} telah menghapus daftar {stack} pada papan {board}",
    "You have created card {card} in list {stack} on board {board}" : "Anda telah membuat kartu {card} didalam daftar {stack} pada papan {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} telah membuat kartu {card} didalam daftar {stack} pada papan {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Anda telah menghapus kartu {card} didalam daftar {stack} pada papan {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} telah menghapus kartu {card} didalam daftar {stack} pada papan {board}",
    "You have renamed the card {before} to {card}" : "Anda telah mengubah nama kartu {before} menjadi {card}",
    "{user} has renamed the card {before} to {card}" : "{user} telah mengubah nama kartu {before} menjadi {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Anda telah menambahkan deskripsi kartu {card} didalam daftar {stack} pada papan {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} telah menambahkan deskripsi kartu {card} didalam daftar {stack} pada papan {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Anda telah memperbarui deskripsi kartu {card} didalam daftar {stack} pada papan {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} telah memperbarui deskripsi kartu {card} didalam daftar {stack} pada papan {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Anda telah mengarsipkan kartu {card} didalam daftar {stack} pada papan {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} telah mengarsipkan kartu {card} didalam daftar {stack} pada papan {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Anda telah memulihkan arsip kartu {card} didalam daftar {stack} pada papan {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} telah memulihkan kartu {card} didalam daftar {stack} pada papan {board}",
    "You have removed the due date of card {card}" : "Anda telah menghapus tenggat kartu {card}",
    "{user} has removed the due date of card {card}" : "{user} telah menghapus tenggat kartu {card}",
    "You have set the due date of card {card} to {after}" : "Anda telah mengatur tenggat kartu {card} ke {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} telah mengatur tenggat kartu {card} ke {after}",
    "You have updated the due date of card {card} to {after}" : "Anda telah memperbarui tenggat kartu {card} ke {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} telah memperbarui tenggat kartu {card} ke {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Anda telah menambahkan label {label} ke kartu {card} didalam daftar {stack} pada papan {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} telah menambahkan label {label} ke kartu {card} didalam daftar {stack} pada papan {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Anda telah menghapus label {label} dari kartu {card} didalam daftar {stack} pada papan {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} telah menghapus label {label} dari kartu {card} didalam daftar {stack} pada papan {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Anda telah menugaskan {assigneduser} ke kartu {card} pada papan {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} telah menugaskan {assigneduser} ke kartu {card} pada papan {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Anda telah tidak menugaskan {assigneduser} ke kartu {card} pada papan {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} telah tidak menugaskan {assigneduser} ke kartu {card} pada papan {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Anda telah memindahkan kartu {card} dari daftar {stackBefore} ke {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} telah memindahkan kartu {card} dari daftar {stackBefore} ke {stack}",
    "You have added the attachment {attachment} to card {card}" : "Anda telah menyematkan lampiran {attachment} ke kartu {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} telah menyematkan lampiran {attachment} ke kartu {card}",
    "You have updated the attachment {attachment} on card {card}" : "Anda telah memperbarui lampiran {attachment} pada kartu {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} telah memperbarui lampiran {attachment} pada kartu {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Anda telah menghapus lampiran {attachment} dari kartu {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} telah menghapus lampiran {attachment} dari kartu {card}",
    "You have restored the attachment {attachment} to card {card}" : "Anda telah memulihkan lampiran {attachment} ke kartu {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} telah memulihkan lampiran {attachment} ke kartu {card}",
    "You have commented on card {card}" : "Anda telah berkomentar pada kartu {card}",
    "{user} has commented on card {card}" : "{user} telah berkomentar pada kartu {card}",
    "Deck" : "Longgok",
    "Changes in the <strong>Deck app</strong>" : "Perubahan pada <strong>aplikasi Longgok</strong>",
    "A <strong>comment</strong> was created on a card" : "<strong>Komentar</strong> telah dibuat pada suatu kartu",
    "The file was uploaded" : "Berkas terunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The file was only partially uploaded" : "Berkas hanya sebagian terunggah",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Could not write file to disk" : "Tidak dapat menulis berkas ke diska",
    "A PHP extension stopped the file upload" : "Ekstensi PHP menghentikan proses unggah berkas",
    "No file uploaded or file size exceeds maximum of %s" : "Gagal unggah berkas atau ukuran melampaui batas maksimum %s",
    "Upcoming cards" : "Kartu berikut",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kartu \"%s\" pada \"%s\" telah ditugaskan kepada Anda oleh %s.",
    "%s has mentioned you in a comment on \"%s\"." : "%s telah menyebut Anda didalam suatu komentar pada \"%s\".",
    "The board \"%s\" has been shared with you by %s." : "Papan \"%s\" telah dibagikan kepada Anda oleh %s.",
    "Deck board" : "Papan Longgok",
    "No data was provided to create an attachment." : "Tidak ada data untuk membuat lampiran.",
    "Finished" : "Selesai",
    "To review" : "Perlu ditinjau",
    "Action needed" : "Butuh tindakan",
    "Later" : "Nanti",
    "copy" : "salin",
    "In Progress" : "Sedang Berlangsung",
    "Done" : "Selesai",
    "Attachments" : "Lampiran",
    "Card not found" : "Kartu tidak ditemukan",
    "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
    "Personal planning and team project organization" : "Perencanaan pribadi dan pengelolaan proyek tim",
    "Add board" : "Tambah papan",
    "Card details" : "Detail kartu",
    "Select the board to link to a project" : "Pilih papan untuk ditautkan ke proyek",
    "Search by board title" : "Cari berdasarkan judul papan",
    "Select board" : "Pilih papan",
    "Select a board" : "Pilih papan",
    "Select a list" : "Pilih daftar",
    "Move card" : "Pindahkan kartu",
    "Select the card to link to a project" : "Pilih kartu untuk ditautkan ke proyek",
    "Link to card" : "Tautan ke kartu",
    "Select a card" : "Pilih kartu",
    "Cancel" : "Membatalkan",
    "This board is read only" : "Papan hanya dapat dilihat",
    "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
    "File already exists" : "Berkas sudah ada",
    "A file with the name {filename} already exists." : "Berkas dengan nama {filename} sudah ada.",
    "Do you want to overwrite it?" : "Apakah Anda ingin menimpanya?",
    "Overwrite file" : "Menimpa berkas",
    "Keep existing file" : "Pertahankan berkas yang ada",
    "Add card" : "Tambah kartu",
    "Archived cards" : "Arsip kartu",
    "Add list" : "Tambahkan daftar",
    "List name" : "Nama daftar",
    "Apply filter" : "Terapkan filter",
    "Filter by tag" : "Filter dengan tag",
    "Filter by assigned user" : "Filter dengan pengguna",
    "Unassigned" : "Belum ditugaskan",
    "Open" : "Buka",
    "Completed" : "Selesai",
    "Filter by due date" : "Filter dengan tenggat",
    "Overdue" : "Lewat tenggat",
    "Next 24 hours" : "Jangka 24 jam",
    "Next 7 days" : "Jangka 7 hari",
    "Next 30 days" : "Jangka 30 hari",
    "No due date" : "Tanpa tenggat",
    "Clear filter" : "Bersihkan filter",
    "Show archived cards" : "Tampilan arsip kartu",
    "Toggle compact mode" : "Beralih mode ringkas",
    "Details" : "Detail",
    "General" : "Umum",
    "Appearance" : "Tampilan",
    "Search" : "Cari",
    "Loading board" : "Memuat papan",
    "Board not found" : "Papan tidak ditemukan",
    "Sharing" : "Berbagi",
    "Tags" : "Tag",
    "Deleted items" : "Entri terhapus",
    "Activity" : "Aktivitas",
    "Deleted lists" : "Daftar terhapus",
    "Undo" : "Undo",
    "Deleted cards" : "Kartu terhapus",
    "Transfer" : "Transfer",
    "Board owner" : "Pemilik papan",
    "(Group)" : "(Grup)",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Can manage" : "Dapat mengelola",
    "Owner" : "Owner",
    "Delete" : "Hapus",
    "Delete list" : "Hapus daftar",
    "Add a new card" : "Tambah kartu baru",
    "title and color value must be provided" : "judul dan nilai warna harus ditentukan",
    "Edit" : "Sunting",
    "Add a new tag" : "Tambah tag baru",
    "Members" : "Anggota",
    "Assign a user to this card…" : "Menugaskan pengguna kepada kartu ini..",
    "Invalid path selected" : "Jalur terpilih invalid",
    "Add this attachment" : "Tambah lampiran ini",
    "Download" : "Unduh",
    "Delete Attachment" : "Hapus Lampiran",
    "Restore Attachment" : "Pulihkan Lampiran",
    "Modified" : "Dimodifikasi",
    "Created" : "Dibuat",
    "Comments" : "Komentar",
    "No comments yet. Begin the discussion!" : "Belum ada komentar. Mulai berdiskusi!",
    "The comment cannot be empty." : "Komentar tidak dapat kosong.",
    "The comment cannot be longer than 1000 characters." : "Komentar tidak dapat melebihi 1000 karakter.",
    "Save" : "Simpan",
    "Created:" : "Dibuat:",
    "In reply to" : "Membalas kepada",
    "Reply" : "Balas",
    "Update" : "Perbarui",
    "Description" : "Deskrisi",
    "(Unsaved)" : "(Tidak tersimpan)",
    "(Saving…)" : "(Menyimpan…)",
    "Formatting help" : "Bantuan pemformatan",
    "Edit description" : "Edit deskripsi.",
    "View description" : "Tampilkan deskripsi",
    "Add Attachment" : "Tambah Lampiran",
    "Choose attachment" : "Pilih lampiran",
    "Set a due date" : "Tentukan tenggat",
    "Remove due date" : "Hapus tenggat",
    "Mark as done" : "Tandai sebagai selesai",
    "Not done" : "Belum selesai",
    "Unarchive card" : "Memulihkan kartu",
    "Archive card" : "Mengarsipkan kartu",
    "Assign a tag to this card…" : "Berikan tag pada kartu ini...",
    "(group)" : "(grup)",
    "Edit title" : "Edit judul",
    "Assign to me" : "Tugaskan saya",
    "Delete card" : "Hapus kartu",
    "seconds ago" : "beberapa detik yang lalu",
    "All boards" : "Semua papan",
    "Archived boards" : "Papan terarsip",
    "Shared with you" : "Shared with you",
    "Cancel edit" : "Batal sunting",
    "Board {0} deleted" : "{0} papan terhapus",
    "An error occurred" : "Terjadi kesalahan",
    "Delete the board?" : "Hapus papan?",
    "Board details" : "Detail papan",
    "Edit board" : "Edit papan",
    "Clone board" : "Pengklonaan papan",
    "Unarchive board" : "Memulihkan papan",
    "Archive board" : "Mengarsipkan papan",
    "No notifications" : "Tidak ada notifikasi",
    "Delete board" : "Hapus papan",
    "Clone cards" : "Klona kartu",
    "Advanced options" : "Opsi lanjutan",
    "Clone" : "Klona",
    "Export" : "Ekspor",
    "Click to expand comment" : "Klik untuk membuka komentar",
    "Close" : "Tutup",
    "No upcoming cards" : "Tidak ada kartu berikut",
    "upcoming cards" : "kartu berikut",
    "Link to a board" : "Tautan ke papan",
    "Link to a card" : "Tautan ke kartu",
    "Something went wrong" : "Ada yang salah",
    "Maximum file size of {size} exceeded" : "Melampaui batas ukuran maksimal {size}",
    "Due date" : "Tenggat",
    "Share" : "Bagikan",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kartu \"%s\" pada \"%s\" telah melampaui tenggat.",
    "To do" : "Akan dikerjakan",
    "Doing" : "Sedang dikerjakan",
    "Example Task 3" : "Contoh tugas 3",
    "Example Task 2" : "Contoh tugas 2",
    "Example Task 1" : "Contoh tugas 1",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Keyboard shortcut" : "Pintasan keyboard",
    "Today" : "Hari ini",
    "Tomorrow" : "Besok"
},
"nplurals=1; plural=0;");
